@@ -97,6 +97,21 @@ SUPPORTED_NETWORK_V2: Dict[str, Tuple[str, str]] = {
     "sepoliaera.zksync": ("300", "sepolia-era.zksync.network"),
     "xai": ("660279", "xaiscan.io"),
     "sepolia.xai": ("37714555429", "sepolia.xaiscan.io"),
+    "xdc": ("50", "xdcscan.com"),
+    "testnet.xdc": ("51", "testnet.xdcscan.com"),
+    "apechain": ("33139", "apescan.io"),
+    "curtis.apechain": ("33111", "curtis.apescan.io"),
+    "world": ("480", "worldscan.org"),
+    "sepolia.world": ("4801", "sepolia.worldscan.org"),
+    "sophon": ("50104", "sophscan.xyz"),
+    "testnet.sophon": ("531050104", "testnet.sophscan.xyz"),
+    "sonic": ("146", "sonicscan.org"),
+    "testnet.sonic": ("57054", "testnet.sonicscan.org"),
+    "unichain": ("130", "uniscan.xyz"),
+    "sepolia.unichain": ("1301", "sepolia.uniscan.xyz"),
+    "abstract": ("2741", "abscan.org"),
+    "sepolia.abstract": ("11124", "sepolia.abscan.org"),
+    "berachain": ("80094", "berascan.com"),
 }
 
 SUPPORTED_NETWORK = {**SUPPORTED_NETWORK_V1, **SUPPORTED_NETWORK_V2}
